<?php
/*
Plugin Name: Upcoming Posts Widget
Plugin URI: https://fabiohuwyler.ch/upcoming-posts-widget/
Description: Displays upcoming posts in a widget
Version: 1.0
Author: Fabio Huwyler
Author URI: https://fabiohuwyler.ch
License: GPL2
*/

// Register the widget
function wpb_load_widget() {
    register_widget( 'upcoming_posts_widget' );
}
add_action( 'widgets_init', 'wpb_load_widget' );

// Create the widget class
class upcoming_posts_widget extends WP_Widget {
    function __construct() {
        parent::__construct(
            'upcoming_posts_widget', // Base ID of your widget
            __( 'Upcoming Posts', 'text_domain' ), // Widget name will appear in UI
            array(
                'description' => __( 'Displays upcoming posts in a widget', 'text_domain' ),
            )
        );
    }

    // Widget output
    public function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );
        $num_posts = $instance['num_posts'];

        echo $args['before_widget'];
        if ( ! empty( $title ) ) {
            echo $args['before_title'] . $title . $args['after_title'];
        }

        // Query for upcoming posts
        $upcoming_posts = new WP_Query( array(
            'posts_per_page' => $num_posts,
            'post_status' => 'future',
            'orderby' => 'date',
            'order' => 'ASC'
        ));

        // Display the posts
        if ( $upcoming_posts->have_posts() ) {
            echo '<ul class="upcoming-posts">';
            while ( $upcoming_posts->have_posts() ) {
                $upcoming_posts->the_post();
                echo '<li><a href="' . get_permalink() . '">' . get_the_title() . '</a><br><span class="post-date">' . get_the_date() . '</span></li>';
            }
            echo '</ul>';
        } else {
            echo '<p>No upcoming posts found</p>';
        }

        wp_reset_postdata();
        echo $args['after_widget'];
    }

    // Widget settings form
    public function form( $instance ) {
        $title = ! empty( $instance['title'] ) ? $instance['title'] : __( 'Upcoming Posts', 'text_domain' );
        $num_posts = ! empty( $instance['num_posts'] ) ? $instance['num_posts'] : 5;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'num_posts' ); ?>"><?php _e( 'Number of posts to display:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'num_posts' ); ?>" name="<?php echo $this->get_field_name( 'num_posts' ); ?>" type="number" value="<?php echo esc_attr( $num_posts ); ?>" min="1" max="10">
        </p>
        <?php
    }
    // Widget settings update
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ! empty( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['num_posts'] = ! empty( $new_instance['num_posts'] ) ? absint( $new_instance['num_posts'] ) : 5;

        return $instance;
    }
}

// Add some CSS styling to the widget
function wpb_add_widget_styles() {
    wp_enqueue_style( 'upcoming-posts-widget-styles', plugins_url( 'upcoming-posts-widget-style.css', __FILE__ ) );
}
add_action( 'wp_enqueue_scripts', 'wpb_add_widget_styles' );
